==> dde-app-services_1.0.27.tar.xz: BUILD/dconfig-center/dde-dconfig-editor/translates/dde-dconfig-editor_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Content</name>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>export</source>
        <translation>导出</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>copy value</source>
        <translation>复制值</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="593"/>
        <source>convert to cmd</source>
        <translation>复制命令</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="594"/>
        <source>reset value</source>
        <translation>重置</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>export current configuration</source>
        <translation>导出当前配置</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>file(*.csv)</source>
        <translation>文件(*.csv)</translation>
    </message>
</context>
<context>
    <name>ExportDialog</name>
    <message>
        <location filename="../exportdialog.cpp" line="22"/>
        <source>select all</source>
        <translation>全选</translation>
    </message>
    <message>
        <location filename="../exportdialog.cpp" line="23"/>
        <source>export</source>
        <translation>导出</translation>
    </message>
    <message>
        <location filename="../exportdialog.cpp" line="49"/>
        <source>content</source>
        <translation>内容</translation>
    </message>
    <message>
        <location filename="../exportdialog.cpp" line="163"/>
        <source>export current configuration</source>
        <translation>导出当前配置</translation>
    </message>
    <message>
        <location filename="../exportdialog.cpp" line="163"/>
        <source>file(*.csv)</source>
        <translation>文件(*.csv)</translation>
    </message>
    <message>
        <location filename="../exportdialog.cpp" line="178"/>
        <source>save failed</source>
        <translation>保存失败</translation>
    </message>
    <message>
        <location filename="../exportdialog.cpp" line="179"/>
        <source>ok</source>
        <translation>确认</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="56"/>
        <source>appid</source>
        <translation>应用Id</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="57"/>
        <source>input filter appid</source>
        <translation>输入应用Id</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="75"/>
        <source>resource</source>
        <translation>配置Id</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="76"/>
        <source>input filter resource</source>
        <translation>输入配置Id</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="93"/>
        <source>keys</source>
        <translation>配置项Key值</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>input filter keys</source>
        <translation>输入配置项Key值</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>setting history</source>
        <translation>修改历史</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>export</source>
        <translation>导出</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <source>OEM</source>
        <translation>定制镜像</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>reset value</source>
        <translation>重置</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>config language</source>
        <translation>配置语言</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>default</source>
        <translation>默认</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>chinese</source>
        <translation>中文</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>english</source>
        <translation>英文</translation>
    </message>
</context>
<context>
    <name>OEMDialog</name>
    <message>
        <location filename="../oemdialog.cpp" line="28"/>
        <source>OEM</source>
        <translation>定制镜像</translation>
    </message>
    <message>
        <location filename="../oemdialog.cpp" line="179"/>
        <source>export directory</source>
        <translation>导出目录</translation>
    </message>
    <message>
        <location filename="../oemdialog.cpp" line="225"/>
        <source>save filed</source>
        <translation>文件保存失败</translation>
    </message>
    <message>
        <location filename="../oemdialog.cpp" line="226"/>
        <location filename="../oemdialog.cpp" line="260"/>
        <location filename="../oemdialog.cpp" line="288"/>
        <source>ok</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../oemdialog.cpp" line="286"/>
        <source>file doesn&apos;t save</source>
        <translation>文件未保存，确认退出</translation>
    </message>
    <message>
        <location filename="../oemdialog.cpp" line="287"/>
        <source>cancle</source>
        <translation>取消</translation>
    </message>
</context>
</TS>

==> dde-app-services_1.0.33.tar.xz: BUILD/dconfig-center/dde-dconfig-editor/translates/dde-dconfig-editor_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Content</name>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>export</source>
        <translation>导出</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>copy value</source>
        <translation>复制值</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="593"/>
        <source>convert to cmd</source>
        <translation>复制命令</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="594"/>
        <source>reset value</source>
        <translation>重置</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>export current configuration</source>
        <translation>导出当前配置</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>file(*.csv)</source>
        <translation>文件(*.csv)</translation>
    </message>
</context>
<context>
    <name>ExportDialog</name>
    <message>
        <location filename="../exportdialog.cpp" line="22"/>
        <source>select all</source>
        <translation>全选</translation>
    </message>
    <message>
        <location filename="../exportdialog.cpp" line="23"/>
        <source>export</source>
        <translation>导出</translation>
    </message>
    <message>
        <location filename="../exportdialog.cpp" line="49"/>
        <source>content</source>
        <translation>内容</translation>
    </message>
    <message>
        <location filename="../exportdialog.cpp" line="163"/>
        <source>export current configuration</source>
        <translation>导出当前配置</translation>
    </message>
    <message>
        <location filename="../exportdialog.cpp" line="163"/>
        <source>file(*.csv)</source>
        <translation>文件(*.csv)</translation>
    </message>
    <message>
        <location filename="../exportdialog.cpp" line="178"/>
        <source>save failed</source>
        <translation>保存失败</translation>
    </message>
    <message>
        <location filename="../exportdialog.cpp" line="179"/>
        <source>ok</source>
        <translation>确认</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="56"/>
        <source>appid</source>
        <translation>应用Id</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="57"/>
        <source>input filter appid</source>
        <translation>输入应用Id</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="75"/>
        <source>resource</source>
        <translation>配置Id</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="76"/>
        <source>input filter resource</source>
        <translation>输入配置Id</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="93"/>
        <source>keys</source>
        <translation>配置项Key值</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>input filter keys</source>
        <translation>输入配置项Key值</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>setting history</source>
        <translation>修改历史</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>export</source>
        <translation>导出</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <source>OEM</source>
        <translation>定制镜像</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>reset value</source>
        <translation>重置</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>config language</source>
        <translation>配置语言</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>default</source>
        <translation>默认</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>chinese</source>
        <translation>中文</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>english</source>
        <translation>英文</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="357"/>
        <source>Switch User</source>
        <translation>切换用户</translation>
    </message>
</context>
<context>
    <name>OEMDialog</name>
    <message>
        <location filename="../oemdialog.cpp" line="28"/>
        <source>OEM</source>
        <translation>定制镜像</translation>
    </message>
    <message>
        <location filename="../oemdialog.cpp" line="179"/>
        <source>export directory</source>
        <translation>导出目录</translation>
    </message>
    <message>
        <location filename="../oemdialog.cpp" line="225"/>
        <source>save filed</source>
        <translation>文件保存失败</translation>
    </message>
    <message>
        <location filename="../oemdialog.cpp" line="226"/>
        <location filename="../oemdialog.cpp" line="260"/>
        <location filename="../oemdialog.cpp" line="288"/>
        <source>ok</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../oemdialog.cpp" line="286"/>
        <source>file doesn&apos;t save</source>
        <translation>文件未保存，确认退出</translation>
    </message>
    <message>
        <location filename="../oemdialog.cpp" line="287"/>
        <source>cancle</source>
        <translation>取消</translation>
    </message>
</context>
</TS>
